@@ -1,5 +1,3 @@
-import sphinx_rtd_theme
-
 # Configuration file for the Sphinx documentation builder.
 #
 # For the full list of built-in configuration values, see the documentation:
@@ -8,30 +6,26 @@ import sphinx_rtd_theme
 # -- Project information -----------------------------------------------------
 # https://www.sphinx-doc.org/en/master/usage/configuration.html#project-information
 
-project = 'pyauditor'
-copyright = '2023, Stefan Kroboth'
-author = 'Stefan Kroboth'
+project = "pyauditor"
+copyright = "2023, Auditor"
+author = "Stefan Kroboth"
 
 # -- General configuration ---------------------------------------------------
 # https://www.sphinx-doc.org/en/master/usage/configuration.html#general-configuration
 
-extensions = [
-        'sphinx.ext.autodoc',
-        'sphinx_rtd_theme',
-        'myst_parser'
-]
+extensions = ["sphinx.ext.autodoc", "sphinx_rtd_theme", "myst_parser"]
 
-templates_path = ['_templates']
-exclude_patterns = ['_build', 'Thumbs.db', '.DS_Store']
+templates_path = ["_templates"]
+exclude_patterns = ["_build", "Thumbs.db", ".DS_Store"]
 
 
 # Interpret first line of docs as function signature
 autodoc_docstring_signature = True
-autodoc_member_order = 'bysource'
+autodoc_member_order = "bysource"
 
 # -- Options for HTML output -------------------------------------------------
 # https://www.sphinx-doc.org/en/master/usage/configuration.html#options-for-html-output
 
-#  html_theme = 'alabaster'
+#  html_theme = "alabaster"
 html_theme = "sphinx_rtd_theme"
-html_static_path = ['_static']
+html_static_path = ["_static"]
