@@ -5,14 +5,13 @@
 // http://opensource.org/licenses/MIT>, at your option. This file may not be
 // copied, modified, or distributed except according to those terms.
 
-use auditor::configuration::{get_configuration, TLSParams};
+use auditor::configuration::{TLSParams, get_configuration};
 use auditor::metrics::DatabaseMetricsWatcher;
 use auditor::startup::run;
 use auditor::telemetry::{get_subscriber, init_subscriber};
 use sqlx::postgres::PgPoolOptions;
-use std::net::TcpListener;
 
-use rustls::{pki_types::PrivateKeyDer, server::WebPkiClientVerifier, RootCertStore, ServerConfig};
+use rustls::{RootCertStore, ServerConfig, pki_types::PrivateKeyDer, server::WebPkiClientVerifier};
 use rustls_pemfile::{certs, pkcs8_private_keys};
 
 use std::{fs::File, io::BufReader, sync::Arc};
@@ -41,13 +40,6 @@ async fn main() -> Result<(), anyhow::Error> {
         db_metrics_watcher_task.monitor().await.unwrap();
     });
 
-    // Create a TcpListener for a given address and port
-    let address = format!(
-        "{}:{}",
-        configuration.application.addr, configuration.application.port
-    );
-    let listener = TcpListener::bind(address)?;
-
     if let Some(tls) = configuration.tls_config {
         // tls config if the use_tls option is set to true
         if tls.use_tls {
@@ -107,7 +99,8 @@ async fn main() -> Result<(), anyhow::Error> {
             };
 
             run(
-                listener,
+                configuration.application.addr,
+                configuration.application.port,
                 connection_pool,
                 db_metrics_watcher,
                 Some(tls_params),
@@ -115,11 +108,25 @@ async fn main() -> Result<(), anyhow::Error> {
             .await?;
         } else {
             // Start server
-            run(listener, connection_pool, db_metrics_watcher, None)?.await?;
+            run(
+                configuration.application.addr,
+                configuration.application.port,
+                connection_pool,
+                db_metrics_watcher,
+                None,
+            )?
+            .await?;
         }
     } else {
         // Start server
-        run(listener, connection_pool, db_metrics_watcher, None)?.await?;
+        run(
+            configuration.application.addr,
+            configuration.application.port,
+            connection_pool,
+            db_metrics_watcher,
+            None,
+        )?
+        .await?;
     }
 
     Ok(())
