@@ -1,4 +1,4 @@
-use auditor::configuration::{get_configuration, DatabaseSettings};
+use auditor::configuration::{DatabaseSettings, get_configuration};
 use auditor::metrics::DatabaseMetricsWatcher;
 use auditor::telemetry::{get_subscriber, init_subscriber};
 use once_cell::sync::Lazy;
@@ -123,13 +123,20 @@ pub async fn spawn_app() -> TestApp {
     let listener = TcpListener::bind("127.0.0.1:0").expect("Failed to bind random port");
     let port = listener.local_addr().unwrap().port();
     let address = format!("http://127.0.0.1:{port}");
+    drop(listener);
 
     let mut configuration = get_configuration().expect("Failed to read configuration.");
     configuration.database.database_name = Uuid::new_v4().to_string();
     let connection_pool = configure_database(&configuration.database).await;
     let db_watcher = DatabaseMetricsWatcher::new(connection_pool.clone(), &configuration).unwrap();
-    let server = auditor::startup::run(listener, connection_pool.clone(), db_watcher, None)
-        .expect("Failed to bind address");
+    let server = auditor::startup::run(
+        "127.0.0.1".to_string(),
+        port,
+        connection_pool.clone(),
+        db_watcher,
+        None,
+    )
+    .expect("Failed to bind address");
     tokio::spawn(server);
     TestApp {
         address,
